Sophie

Sophie

distrib > Mandriva > 2008.0 > x86_64 > media > main-backports-src > by-pkgid > ce2f6a9e601f43f012216a8b9fa9dfda > files > 1

ufraw-0.13-3mdv2008.0.src.rpm

diff -p -up ufraw-0.13/ufraw_developer.c.cvsfixes ufraw-0.13/ufraw_developer.c
--- ufraw-0.13/ufraw_developer.c.cvsfixes	2007-11-11 02:28:56.000000000 +0100
+++ ufraw-0.13/ufraw_developer.c	2007-12-29 11:08:48.000000000 +0100
@@ -342,7 +342,7 @@ void developer_prepare(developer_data *d
     unsigned exposure = pow(2, conf->exposure) * 0x10000;
     /* Handle the exposure normalization for Canon EOS cameras. */
     if ( conf->ExposureNorm>0 )
-	exposure = exposure * d->rgbMax / conf->ExposureNorm;
+	exposure = (guint64)exposure * d->rgbMax / conf->ExposureNorm;
     if ( exposure>=0x10000 ) d->restoreDetails = clip_details;
     if ( exposure<=0x10000 ) clipHighlights = digital_highlights;
     /* Check if gamma curve data has changed. */
diff -p -up ufraw-0.13/uf_gtk.h.cvsfixes ufraw-0.13/uf_gtk.h
--- ufraw-0.13/uf_gtk.h.cvsfixes	2007-12-29 11:31:57.000000000 +0100
+++ ufraw-0.13/uf_gtk.h	2007-12-29 11:32:46.000000000 +0100
@@ -26,6 +26,8 @@ void uf_widget_set_tooltip(GtkWidget *wi
 
 void uf_button_set_stock_image(GtkButton *button, const gchar *stock_image);
 
+void uf_label_set_width_chars(GtkLabel *label, gint n_chars);
+
 // Interface to gtk_window_set_icon_name() introduced in 2.6
 void uf_window_set_icon_name(GtkWindow *window, const gchar *name);
 
diff -p -up ufraw-0.13/uf_gtk.cc.cvsfixes ufraw-0.13/uf_gtk.cc
--- ufraw-0.13/uf_gtk.cc.cvsfixes	2007-11-11 01:56:57.000000000 +0100
+++ ufraw-0.13/uf_gtk.cc	2007-12-29 11:25:11.000000000 +0100
@@ -96,6 +96,16 @@ void uf_window_set_icon_name(GtkWindow *
 #endif
 }
 
+void uf_label_set_width_chars(GtkLabel *label, gint n_chars)
+{
+#if GTK_CHECK_VERSION(2,6,0)
+    gtk_label_set_width_chars(label, n_chars);
+#else
+    (void)label;
+    (void)n_chars;
+#endif
+}
+
 // Get the display ICC profile of the monitor associated with the widget.
 // For X display, uses the ICC profile specifications version 0.2 from
 // http://burtonini.com/blog/computers/xicc
diff -p -up ufraw-0.13/ufraw_preview.c.cvsfixes ufraw-0.13/ufraw_preview.c
--- ufraw-0.13/ufraw_preview.c.cvsfixes	2007-11-11 03:11:19.000000000 +0100
+++ ufraw-0.13/ufraw_preview.c	2007-12-29 11:28:52.000000000 +0100
@@ -539,10 +539,20 @@ static colorLabels *color_labels_new(Gtk
 	gtk_container_add(GTK_CONTAINER(event_box), GTK_WIDGET(l->labels[c]));
 	gtk_table_attach(table, event_box, x+i, x+i+1, y, y+1,
 		GTK_EXPAND|GTK_FILL, 0, 0, 0);
-	if ( c==3 )
-	    uf_widget_set_tooltip(event_box, _("Luminosity (Y value)"));
-	if ( c==4 )
-	    uf_widget_set_tooltip(event_box, _("Adams' zone"));
+	switch (c)
+	{
+	case 0: case 1: case 2:
+	    uf_label_set_width_chars(l->labels[c], 3);
+            break;
+	case 3:
+	    uf_label_set_width_chars(l->labels[c], 5);
+            uf_widget_set_tooltip(event_box, _("Luminosity (Y value)"));
+	    break;
+        case 4:
+	    uf_label_set_width_chars(l->labels[c], 4);
+            uf_widget_set_tooltip(event_box, _("Adams' zone"));
+	    break;
+        }
     }
     return l;
 }
diff -p -up ufraw-0.13/wb_presets.c.cvsfixes ufraw-0.13/wb_presets.c
--- ufraw-0.13/wb_presets.c.cvsfixes	2007-11-11 01:36:27.000000000 +0100
+++ ufraw-0.13/wb_presets.c	2007-12-29 11:08:48.000000000 +0100
@@ -44,13 +44,18 @@ static const char IncandescentWarm[] = N
 // Same as "Incandescent":
 static const char Tungsten[] = N_("Tungsten");
 static const char Fluorescent[] = N_("Fluorescent");
 // Only in Canon cameras:
 static const char FluorescentHigh[] = N_("Fluorescent high");
 static const char CoolWhiteFluorescent[] = N_("Cool white fluorescent");
 static const char WarmWhiteFluorescent[] = N_("Warm white fluorescent");
 static const char DaylightFluorescent[] = N_("Daylight fluorescent");
 static const char NeutralFluorescent[] = N_("Neutral fluorescent");
 static const char WhiteFluorescent[] = N_("White fluorescent");
+// In Nikon D300
+static const char SodiumVaporFluorescent[] = N_("Sodium-vapor fluorescent");
+static const char DayWhiteFluorescent[] = N_("Day white fluorescent");
+static const char HighTempMercuryVaporFluorescent[] = N_("High temp. mercury-vapor fluorescent");
+
 static const char Flash[] = N_("Flash");
 // For Olympus with no real "Flash" preset:
 static const char FlashAuto[] = N_("Flash (auto mode)");
@@ -229,21 +234,21 @@ const wb_data wb_preset[] = {
   { "Canon", "EOS 400D DIGITAL", Daylight, 0,	{ 2.230469, 1, 1.464844, 0 } },
   { "Canon", "EOS 400D DIGITAL", Shade, 0,	{ 2.660156, 1, 1.214844, 0 } },
   { "Canon", "EOS 400D DIGITAL", Cloudy, 0,	{ 2.444336, 1, 1.328125, 0 } },
-  { "Canon", "EOS 400D DIGITAL", Incandescent, 0, { 2.444336, 1, 1.328125, 0 } },
+  { "Canon", "EOS 400D DIGITAL", Incandescent, 0, { 1.472948, 1, 2.310634, 0 } },
   { "Canon", "EOS 400D DIGITAL", Fluorescent, 0, { 1.834783, 1, 2.065701, 0 } },
   { "Canon", "EOS 400D DIGITAL", Flash, 0,	{ 2.503906, 1, 1.299805, 0 } },
 
   { "Canon", "EOS DIGITAL REBEL XTi", Daylight, 0, { 2.230469, 1, 1.464844, 0 } },
   { "Canon", "EOS DIGITAL REBEL XTi", Shade, 0,	{ 2.660156, 1, 1.214844, 0 } },
   { "Canon", "EOS DIGITAL REBEL XTi", Cloudy, 0, { 2.444336, 1, 1.328125, 0 } },
-  { "Canon", "EOS DIGITAL REBEL XTi", Incandescent, 0, { 2.444336, 1, 1.328125, 0 } },
+  { "Canon", "EOS DIGITAL REBEL XTi", Incandescent, 0, { 1.472948, 1, 2.310634, 0 } },
   { "Canon", "EOS DIGITAL REBEL XTi", Fluorescent, 0, { 1.834783, 1, 2.065701, 0 } },
   { "Canon", "EOS DIGITAL REBEL XTi", Flash, 0,	{ 2.503906, 1, 1.299805, 0 } },
 
   { "Canon", "EOS Kiss Digital X", Daylight, 0,	{ 2.230469, 1, 1.464844, 0 } },
   { "Canon", "EOS Kiss Digital X", Shade, 0,	{ 2.660156, 1, 1.214844, 0 } },
   { "Canon", "EOS Kiss Digital X", Cloudy, 0,	{ 2.444336, 1, 1.328125, 0 } },
-  { "Canon", "EOS Kiss Digital X", Incandescent, 0, { 2.444336, 1, 1.328125, 0 } },
+  { "Canon", "EOS Kiss Digital X", Incandescent, 0, { 1.472948, 1, 2.310634, 0 } },
   { "Canon", "EOS Kiss Digital X", Fluorescent, 0, { 1.834783, 1, 2.065701, 0 } },
   { "Canon", "EOS Kiss Digital X", Flash, 0,	{ 2.503906, 1, 1.299805, 0 } },
 
@@ -943,6 +948,43 @@ const wb_data wb_preset[] = {
   { "NIKON", "D200", "9300K", 0,		{ 2.367188, 1, 1.070313, 0 } },
   { "NIKON", "D200", "10000K", 0,		{ 2.453125, 1, 1.035156, 0 } },
 
+  { "NIKON", "D300", Incandescent, -6,			{ 1.097656, 1.000000, 1.898438, 0 } },
+  { "NIKON", "D300", Incandescent, 0,			{ 1.019531, 1.000000, 2.109375, 0 } },
+  { "NIKON", "D300", Incandescent, 6,			{ 1.000000, 1.000000, 2.335938, 0 } },
+  { "NIKON", "D300", SodiumVaporFluorescent, -6,	{ 1.031250, 1.000000, 2.101563, 0 } },
+  { "NIKON", "D300", SodiumVaporFluorescent, 0,		{ 1.000000, 1.053498, 2.444444, 0 } },
+  { "NIKON", "D300", SodiumVaporFluorescent, 6,		{ 1.000000, 1.053498, 2.753086, 0 } },
+  { "NIKON", "D300", WarmWhiteFluorescent, -6,		{ 1.128906, 1.000000, 1.847656, 0 } },
+  { "NIKON", "D300", WarmWhiteFluorescent, 0,		{ 1.046875, 1.000000, 1.960937, 0 } },
+  { "NIKON", "D300", WarmWhiteFluorescent, 6,		{ 1.000000, 1.000000, 2.062500, 0 } },
+  { "NIKON", "D300", WhiteFluorescent, -6,		{ 1.453125, 1.000000, 2.050781, 0 } },
+  { "NIKON", "D300", WhiteFluorescent, 0,		{ 1.191406, 1.000000, 2.304688, 0 } },
+  { "NIKON", "D300", WhiteFluorescent, 6,		{ 1.000000, 1.000000, 2.582031, 0 } },
+  { "NIKON", "D300", CoolWhiteFluorescent, -6,		{ 1.667969, 1.000000, 1.800781, 0 } },
+  { "NIKON", "D300", CoolWhiteFluorescent, 0,		{ 1.468750, 1.000000, 2.035156, 0 } },
+  { "NIKON", "D300", CoolWhiteFluorescent, 6,		{ 1.210938, 1.000000, 2.289063, 0 } },
+  { "NIKON", "D300", DayWhiteFluorescent, -6,		{ 1.625000, 1.000000, 1.195312, 0 } },
+  { "NIKON", "D300", DayWhiteFluorescent, 0,		{ 1.492187, 1.000000, 1.363281, 0 } },
+  { "NIKON", "D300", DayWhiteFluorescent, 6,		{ 1.375000, 1.000000, 1.519531, 0 } },
+  { "NIKON", "D300", DaylightFluorescent, -6,		{ 1.851563, 1.000000, 1.000000, 0 } },
+  { "NIKON", "D300", DaylightFluorescent, 0,		{ 1.699219, 1.000000, 1.101562, 0 } },
+  { "NIKON", "D300", DaylightFluorescent, 6,		{ 1.562500, 1.000000, 1.273438, 0 } },
+  { "NIKON", "D300", HighTempMercuryVaporFluorescent,-6,{ 2.039063, 1.000000, 1.156250, 0 } },
+  { "NIKON", "D300", HighTempMercuryVaporFluorescent, 0,{ 1.960937, 1.000000, 1.328125, 0 } },
+  { "NIKON", "D300", HighTempMercuryVaporFluorescent, 6,{ 1.855469, 1.000000, 1.523438, 0 } },
+  { "NIKON", "D300", DirectSunlight, -6,		{ 1.687500, 1.000000, 1.167969, 0 } },
+  { "NIKON", "D300", DirectSunlight, 0,			{ 1.562500, 1.000000, 1.308594, 0 } },
+  { "NIKON", "D300", DirectSunlight, 6,			{ 1.429687, 1.000000, 1.457031, 0 } },
+  { "NIKON", "D300", Flash, -6,				{ 1.910156, 1.000000, 1.058594, 0 } },
+  { "NIKON", "D300", Flash, 0,				{ 1.687500, 1.000000, 1.152344, 0 } },
+  { "NIKON", "D300", Flash, 6,				{ 1.554688, 1.000000, 1.246094, 0 } },
+  { "NIKON", "D300", Cloudy, -6,			{ 1.820313, 1.000000, 1.093750, 0 } },
+  { "NIKON", "D300", Cloudy, 0,				{ 1.664062, 1.000000, 1.187500, 0 } },
+  { "NIKON", "D300", Cloudy, 6,				{ 1.542969, 1.000000, 1.335938, 0 } },
+  { "NIKON", "D300", Shade, -6,				{ 2.156250, 1.000000, 1.000000, 0 } },
+  { "NIKON", "D300", Shade, 0,				{ 1.902344, 1.000000, 1.066406, 0 } },
+  { "NIKON", "D300", Shade, 6,				{ 1.722656, 1.000000, 1.140625, 0 } },
+
   { "NIKON", "D40", Incandescent, -3,		{ 1.492188, 1, 2.164063, 0 } },
   { "NIKON", "D40", Incandescent, -2,		{ 1.437500, 1, 2.367188, 0 } },
   { "NIKON", "D40", Incandescent, -1,		{ 1.417969, 1, 2.414062, 0 } },
@@ -1701,6 +1743,27 @@ const wb_data wb_preset[] = {
   { "SONY", "DSLR-A100", Flash, 0,		{ 1.859375, 1, 1.746094, 0 } },
   { "SONY", "DSLR-A100", Flash, 3,		{ 2.046875, 1, 1.542969, 0 } },
 
+  /* Sony A700 presets - firmware v2 */
+  { "SONY", "DSLR-A700", Daylight, -3,		{ 1.937500, 1, 1.640625, 0 } },
+  { "SONY", "DSLR-A700", Daylight, 0,		{ 2.101563, 1, 1.484375, 0 } },
+  { "SONY", "DSLR-A700", Daylight, 3,		{ 2.273437, 1, 1.343750, 0 } },
+  { "SONY", "DSLR-A700", Shade, -3,		{ 2.257812, 1, 1.359375, 0 } },
+  { "SONY", "DSLR-A700", Shade, 0,		{ 2.445313, 1, 1.226563, 0 } },
+  { "SONY", "DSLR-A700", Shade, 3,		{ 2.652344, 1, 1.113281, 0 } },
+  { "SONY", "DSLR-A700", Cloudy, -3,		{ 2.070312, 1, 1.507812, 0 } },
+  { "SONY", "DSLR-A700", Cloudy, 0,		{ 2.250000, 1, 1.367188, 0 } },
+  { "SONY", "DSLR-A700", Cloudy, 3,		{ 2.429688, 1, 1.234375, 0 } },
+  { "SONY", "DSLR-A700", Tungsten, -3,		{ 1.230469, 1, 2.859375, 0 } },
+  { "SONY", "DSLR-A700", Tungsten, 0,		{ 1.335938, 1, 2.597656, 0 } },
+  { "SONY", "DSLR-A700", Tungsten, 3,		{ 1.449219, 1, 2.343750, 0 } },
+  { "SONY", "DSLR-A700", Fluorescent, -2,	{ 1.292969, 1, 3.199219, 0 } },
+  { "SONY", "DSLR-A700", Fluorescent, 0,	{ 1.878906, 1, 2.152344, 0 } },
+  { "SONY", "DSLR-A700", Fluorescent, 3,	{ 2.433594, 1, 1.539063, 0 } },
+  { "SONY", "DSLR-A700", Fluorescent, 4,	{ 2.273437, 1, 1.347656, 0 } },
+  { "SONY", "DSLR-A700", Flash, -3,		{ 2.128906, 1, 1.460937, 0 } },
+  { "SONY", "DSLR-A700", Flash, 0,		{ 2.277344, 1, 1.312500, 0 } },
+  { "SONY", "DSLR-A700", Flash, 3,		{ 2.496094, 1, 1.199219, 0 } },
+
 };
 
 const int wb_preset_count = sizeof(wb_preset) / sizeof(wb_data);
@@ -44,13 +44,18 @@ static const char IncandescentWarm[] = N
 static const char Tungsten[] = N_("Tungsten");
 static const char Fluorescent[] = N_("Fluorescent");
-// Only in Canon cameras:
+// In Canon cameras and Nikon D300:
 static const char FluorescentHigh[] = N_("Fluorescent high");
 static const char CoolWhiteFluorescent[] = N_("Cool white fluorescent");